---
name: General issue
about: General issue.
title: ''
labels: ''
assignees: ''

---

## Deadline

<!-- e.g., yyyy-MM-dd -->

## Requirements

<!--
e.g.,

All the following issues are resolved.

- #1
- #2
-->

## Tasks

<!--
e.g.,

- [ ] Task A
- [ ] Task B
-->

## Goal

Completion of all the tasks.

## Description

## References

<!--
e.g.,

- [Reference A](https://example.com/)
- #3
-->
